/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.custom.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.custom.entity.BottleCap;
import org.springblade.modules.custom.vo.BottleCapVO;
import org.springblade.modules.custom.wrapper.BottleCapWrapper;
import org.springblade.modules.custom.service.IBottleCapService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 瓶盖表 控制器
 *
 * @author BladeX
 * @since 2023-02-07
 */
@RestController
@AllArgsConstructor
@RequestMapping("custom/bottlecap")
@Api(value = "瓶盖表", tags = "瓶盖表接口")
public class BottleCapController extends BladeController {

	private final IBottleCapService bottleCapService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入bottleCap")
	public R<BottleCapVO> detail(BottleCap bottleCap) {
		BottleCap detail = bottleCapService.getOne(Condition.getQueryWrapper(bottleCap));
		return R.data(BottleCapWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 瓶盖表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入bottleCap")
	public R<IPage<BottleCapVO>> list(BottleCap bottleCap, Query query) {
		IPage<BottleCap> pages = bottleCapService.page(Condition.getPage(query), Condition.getQueryWrapper(bottleCap));
		return R.data(BottleCapWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 瓶盖表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入bottleCap")
	public R<IPage<BottleCapVO>> page(BottleCapVO bottleCap, Query query) {
		IPage<BottleCapVO> pages = bottleCapService.selectBottleCapPage(Condition.getPage(query), bottleCap);
		return R.data(pages);
	}

	/**
	 * 新增 瓶盖表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入bottleCap")
	public R save(@Valid @RequestBody BottleCap bottleCap) {
		return R.status(bottleCapService.save(bottleCap));
	}

	/**
	 * 修改 瓶盖表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入bottleCap")
	public R update(@Valid @RequestBody BottleCap bottleCap) {
		return R.status(bottleCapService.updateById(bottleCap));
	}

	/**
	 * 新增或修改 瓶盖表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入bottleCap")
	public R submit(@Valid @RequestBody BottleCap bottleCap) {
		return R.status(bottleCapService.saveOrUpdate(bottleCap));
	}

	
	/**
	 * 删除 瓶盖表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(bottleCapService.removeByIds(Func.toLongList(ids)));
	}

	
}
