/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.custom.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.custom.entity.WineBox;
import org.springblade.modules.custom.vo.WineBoxVO;
import org.springblade.modules.custom.wrapper.WineBoxWrapper;
import org.springblade.modules.custom.service.IWineBoxService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 酒盒表 控制器
 *
 * @author BladeX
 * @since 2023-02-07
 */
@RestController
@AllArgsConstructor
@RequestMapping("custom/winebox")
@Api(value = "酒盒表", tags = "酒盒表接口")
public class WineBoxController extends BladeController {

	private final IWineBoxService wineBoxService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入wineBox")
	public R<WineBoxVO> detail(WineBox wineBox) {
		WineBox detail = wineBoxService.getOne(Condition.getQueryWrapper(wineBox));
		return R.data(WineBoxWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 酒盒表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入wineBox")
	public R<IPage<WineBoxVO>> list(WineBox wineBox, Query query) {
		IPage<WineBox> pages = wineBoxService.page(Condition.getPage(query), Condition.getQueryWrapper(wineBox));
		return R.data(WineBoxWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 酒盒表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入wineBox")
	public R<IPage<WineBoxVO>> page(WineBoxVO wineBox, Query query) {
		IPage<WineBoxVO> pages = wineBoxService.selectWineBoxPage(Condition.getPage(query), wineBox);
		return R.data(pages);
	}

	/**
	 * 新增 酒盒表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入wineBox")
	public R save(@Valid @RequestBody WineBox wineBox) {
		return R.status(wineBoxService.save(wineBox));
	}

	/**
	 * 修改 酒盒表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入wineBox")
	public R update(@Valid @RequestBody WineBox wineBox) {
		return R.status(wineBoxService.updateById(wineBox));
	}

	/**
	 * 新增或修改 酒盒表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入wineBox")
	public R submit(@Valid @RequestBody WineBox wineBox) {
		return R.status(wineBoxService.saveOrUpdate(wineBox));
	}

	
	/**
	 * 删除 酒盒表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(wineBoxService.removeByIds(Func.toLongList(ids)));
	}

	
}
