/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.custom.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.custom.entity.WineCase;
import org.springblade.modules.custom.vo.WineCaseVO;
import org.springblade.modules.custom.wrapper.WineCaseWrapper;
import org.springblade.modules.custom.service.IWineCaseService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 酒箱表 控制器
 *
 * @author BladeX
 * @since 2023-02-07
 */
@RestController
@AllArgsConstructor
@RequestMapping("custom/winecase")
@Api(value = "酒箱表", tags = "酒箱表接口")
public class WineCaseController extends BladeController {

	private final IWineCaseService wineCaseService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入wineCase")
	public R<WineCaseVO> detail(WineCase wineCase) {
		WineCase detail = wineCaseService.getOne(Condition.getQueryWrapper(wineCase));
		return R.data(WineCaseWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 酒箱表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入wineCase")
	public R<IPage<WineCaseVO>> list(WineCase wineCase, Query query) {
		IPage<WineCase> pages = wineCaseService.page(Condition.getPage(query), Condition.getQueryWrapper(wineCase));
		return R.data(WineCaseWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 酒箱表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入wineCase")
	public R<IPage<WineCaseVO>> page(WineCaseVO wineCase, Query query) {
		IPage<WineCaseVO> pages = wineCaseService.selectWineCasePage(Condition.getPage(query), wineCase);
		return R.data(pages);
	}

	/**
	 * 新增 酒箱表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入wineCase")
	public R save(@Valid @RequestBody WineCase wineCase) {
		return R.status(wineCaseService.save(wineCase));
	}

	/**
	 * 修改 酒箱表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入wineCase")
	public R update(@Valid @RequestBody WineCase wineCase) {
		return R.status(wineCaseService.updateById(wineCase));
	}

	/**
	 * 新增或修改 酒箱表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入wineCase")
	public R submit(@Valid @RequestBody WineCase wineCase) {
		return R.status(wineCaseService.saveOrUpdate(wineCase));
	}

	
	/**
	 * 删除 酒箱表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(wineCaseService.removeByIds(Func.toLongList(ids)));
	}

	
}
